@@ -225,7 +225,7 @@ void probe_security_bprm_committed_creds(struct linux_binprm *bprm)
 #if defined(CONFIG_ARM64)
 
 /**
- * probe_security_hook_heads_on_arm - Find security_hook_heads on ARM64.
+ * probe_security_hook_heads_on_arm64 - Find security_hook_heads on ARM64.
  *
  * @base: Address of security_bprm_committed_creds().
  *
@@ -261,7 +261,7 @@ static void * __init probe_security_hook_heads_on_arm64(unsigned int *base)
 		tmp += offset;
 		/*
 		 * Find
-		 *   ldr Xt, Xn, #uimm12
+		 *   ldr Xt, [Xn, #uimm12]
 		 * sequence.
 		 */
 		for (ip += 2; i < 32 - 2; ip++, i++) {
@@ -274,6 +274,38 @@ static void * __init probe_security_hook_heads_on_arm64(unsigned int *base)
 		}
 		break;
 	}
+	for (i = 0; i < 32; ip++, i++) {
+		unsigned long tmp;
+		unsigned long offset;
+
+		/*
+		 * Find
+		 *   adrp Xd, #imm21
+		 * sequence.
+		 */
+		if ((*ip & 0x9F000000) != 0x90000000)
+			continue;
+		tmp = ((unsigned long) ip) & ~0xFFFUL;
+		offset = (unsigned long) (((((*ip >> 5) & 0x007FFFF) << 2) |
+					   ((*ip >> 29) & 0x3))) << 12;
+		if (offset & 0x100000000UL)
+			offset |= 0xFFFFFFFF00000000UL;
+		tmp += offset;
+		/*
+		 * Find
+		 *   ldr Xt, [Xn, #uimm12]
+		 * sequence.
+		 */
+		for (ip += 1; i < 32 - 1; ip++, i++) {
+			if ((*ip & 0xFFC00000) != 0xF9400000)
+				continue;
+			offset = ((*ip >> 10) & 0xFFF) << 3;
+			tmp += offset;
+			ip4ret = (unsigned int *) tmp;
+			return &ip4ret;
+		}
+		break;
+	}
 	return NULL;
 }
 
